[−][src]Enum script_traits::script_msg::ScriptMsg
Messages from the script to the constellation.
Variants
CompleteMessagePortTransfer(MessagePortRouterId, Vec<MessagePortId>)Request to complete the transfer of a set of ports to a router.
MessagePortTransferResult(Option<MessagePortRouterId>, Vec<MessagePortId>, HashMap<MessagePortId, VecDeque<PortMessageTask>>)The results of attempting to complete the transfer of a batch of ports.
NewMessagePort(MessagePortRouterId, MessagePortId)A new message-port was created or transferred, with corresponding control-sender.
NewMessagePortRouter(MessagePortRouterId, IpcSender<MessagePortMsg>)A global has started managing message-ports
RemoveMessagePortRouter(MessagePortRouterId)A global has stopped managing message-ports
RerouteMessagePort(MessagePortId, PortMessageTask)A task requires re-routing to an already shipped message-port.
MessagePortShipped(MessagePortId)A message-port was shipped, let the entangled port know.
RemoveMessagePort(MessagePortId)A message-port has been discarded by script.
EntanglePorts(MessagePortId, MessagePortId)Entangle two message-ports.
NewBroadcastChannelRouter(BroadcastChannelRouterId, IpcSender<BroadcastMsg>, ImmutableOrigin)A global has started managing broadcast-channels.
RemoveBroadcastChannelRouter(BroadcastChannelRouterId, ImmutableOrigin)A global has stopped managing broadcast-channels.
NewBroadcastChannelNameInRouter(BroadcastChannelRouterId, String, ImmutableOrigin)A global started managing broadcast channels for a given channel-name.
RemoveBroadcastChannelNameInRouter(BroadcastChannelRouterId, String, ImmutableOrigin)A global stopped managing broadcast channels for a given channel-name.
ScheduleBroadcast(BroadcastChannelRouterId, BroadcastMsg)Broadcast a message to all same-origin broadcast channels, excluding the source of the broadcast.
ForwardToEmbedder(EmbedderMsg)Forward a message to the embedder.
Requests are sent to constellation and fetches are checked manually for cross-origin loads
Broadcast a storage event to every same-origin pipeline. The strings are key, old value and new value.
ChangeRunningAnimationsState(AnimationState)Indicates whether this pipeline is currently running animations.
Requests that a new 2D canvas thread be created. (This is done in the constellation because 2D canvases may use the GPU and we don't want to give untrusted content access to the GPU.)
Notifies the constellation that this frame has received focus.
GetTopForBrowsingContext(BrowsingContextId, IpcSender<Option<TopLevelBrowsingContextId>>)Get the top-level browsing context info for a given browsing context.
GetBrowsingContextInfo(PipelineId, IpcSender<Option<(BrowsingContextId, Option<PipelineId>)>>)Get the browsing context id of the browsing context in which pipeline is embedded and the parent pipeline id of that browsing context.
GetChildBrowsingContextId(BrowsingContextId, usize, IpcSender<Option<BrowsingContextId>>)Get the nth child browsing context ID for a given browsing context, sorted in tree order.
All pending loads are complete, and the load event for this pipeline
has been dispatched.
LoadUrl(LoadData, HistoryEntryReplacement)A new load has been requested, with an option to replace the current entry once loaded instead of adding a new entry.
Abort loading after sending a LoadUrl message.
Post a message to the currently active window of a given browsing context.
Fields of PostMessage
target: BrowsingContextIdThe target of the posted message.
source: PipelineIdThe source of the posted message.
target_origin: Option<ImmutableOrigin>The expected origin of the target.
source_origin: ImmutableOriginThe source origin of the message. https://html.spec.whatwg.org/multipage/#dom-messageevent-origin
data: StructuredSerializedDataThe data to be posted.
Inform the constellation that a fragment was navigated to and whether or not it was a replacement navigation.
TraverseHistory(TraversalDirection)HTMLIFrameElement Forward or Back traversal.
PushHistoryState(HistoryStateId, ServoUrl)Inform the constellation of a pushed history state.
ReplaceHistoryState(HistoryStateId, ServoUrl)Inform the constellation of a replaced history state.
Gets the length of the joint session history from the constellation.
RemoveIFrame(BrowsingContextId, IpcSender<Vec<PipelineId>>)Notification that this iframe should be removed. Returns a list of pipelines which were closed.
VisibilityChangeComplete(bool)Notifies constellation that an iframe's visibility has been changed.
ScriptLoadedURLInIFrame(IFrameLoadInfoWithData)A load has been requested in an IFrame.
ScriptNewIFrame(IFrameLoadInfoWithData, IpcSender<LayoutControlMsg>)A load of the initial about:blank has been completed in an IFrame.
ScriptNewAuxiliary(AuxiliaryBrowsingContextLoadInfo, IpcSender<LayoutControlMsg>)Script has opened a new auxiliary browsing context.
Mark a new document as active
SetDocumentState(DocumentState)Set the document state for a pipeline (used by screenshot / reftests)
SetFinalUrl(ServoUrl)Update the pipeline Url, which can change after redirections.
TouchEventProcessed(EventResult)Script has handled a touch event, and either prevented or allowed default actions.
A log entry, with the top-level browsing context id and thread name
Discard the document.
Discard the browsing context.
Notifies the constellation that this pipeline has exited.
ForwardDOMMessage(DOMMessage, ServoUrl)Send messages from postMessage calls from serviceworker to constellation for storing in service worker manager
ScheduleJob(Job)https://w3c.github.io/ServiceWorker/#schedule-job-algorithm.
GetClientWindow(IpcSender<(DeviceIntSize, DeviceIntPoint)>)Get Window Informations size and position
GetScreenSize(IpcSender<DeviceIntSize>)Get the screen size (pixel)
GetScreenAvailSize(IpcSender<DeviceIntSize>)Get the available screen size (pixel)
MediaSessionEvent(PipelineId, MediaSessionEvent)Notifies the constellation about media session events (i.e. when there is metadata for the active media session, playback state changes...).
RequestAdapter(IpcSender<WebGPUResponseResult>, RequestAdapterOptions, SmallVec<[AdapterId; 4]>)Create a WebGPU Adapter instance
Get WebGPU channel
TitleChanged(PipelineId, String)Notify the constellation of a pipeline's document's title.